.. _api:

API Reference
============

This page provides detailed documentation of the NagaNLP API.

PosTagger
---------

.. autoclass:: naganlp.transformer_tagger.PosTagger
   :members:
   :inherited-members:
   :show-inheritance:

Translator
----------

.. autoclass:: naganlp.nmt_translator.Translator
   :members:
   :inherited-members:
   :show-inheritance:

SubwordTokenizer
----------------

.. autoclass:: naganlp.subword_tokenizer.SubwordTokenizer
   :members:
   :inherited-members:
   :show-inheritance:

NltkPosTagger
-------------

.. autoclass:: naganlp.nltk_tagger.NltkPosTagger
   :members:
   :inherited-members:
   :show-inheritance:

Utility Functions
----------------

.. automodule:: naganlp.utils
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
----------

.. automodule:: naganlp.exceptions
   :members:
   :undoc-members:
   :show-inheritance:
